#!/usr/bin/python

from django.core.management.base import NoArgsCommand

from common import launchpad
from teams import models

from datetime import datetime

class Command(NoArgsCommand):
    help = "Pull list of LoCo Teams from Launchpad and add them to the DB."

    def handle_noargs(self, **options):
        lp = launchpad.lp_login()
        TEAM_BLACKLIST = (u"ubuntu-lococouncil", u"ubuntu-games-merged")
        
        existing_locos = models.Team.objects.all()
        locos = filter(lambda a: a.is_team and a.name not in TEAM_BLACKLIST, 
                       lp.people["locoteams"].members)
        for l in locos:
            if not existing_locos or l.name not in [b.lp_name for b in existing_locos]:
                team = models.Team(lp_name=l.name, name=l.display_name, owner=l.team_owner.name)
                team.save()
            else:
                team = filter(lambda a: a.lp_name == l.name, existing_locos)[0]
                team.name = l.display_name
                team.owner = l.team_owner.name
                for admin in team.admins.all():
                    admin.delete()
            for lp_admin in l.getMembersByStatus(status='Administrator'):
                admin = models.TeamAdministrator(lpid=lp_admin.name)
                admin.save()
                team.admins.add(admin)
            approved_entry = filter(lambda a: a.team.name == u"locoteams-approved", l.memberships_details)
            if approved_entry:
                approval = approved_entry[0]
                if not team.approved:
                    team.approved = True
                if team.approved:
                    if isinstance(approval.date_expires, unicode):
                        try:
                            team.expires_date = datetime.strptime(approval.date_expires[:19], "%Y-%m-%dT%H:%M:%S")
                        except ValueError:
                            team.expires_date = datetime.strptime(approval.date_expires[:11], "%Y-%m-%d")
                    else:
                        team.expires_date = approval.date_expires
            team.save()
