from django.db import models
from django.utils.translation import ugettext as _

class TeamManager(models.Manager):
    pass

class TeamAdministrator(models.Model):
    lpid = models.SlugField(_("Launchpad ID"), max_length=40, null=False, blank=False)
    def __unicode__(self):
       return u'%s' % (self.lpid)

class Team(models.Model):
    lp_name = models.SlugField(_("Launchpad Team ID"), max_length=40, null=True)
    name = models.CharField(_("Team Name"), max_length=80, null=True)
    country = models.CharField(_("Country"), max_length=50, null=True, blank=True)
    spr = models.CharField(_("State/Province/Region"), max_length=50, null=True, blank=True)
    city = models.CharField(_("City"), max_length=50, null=True, blank=True)
    wiki_url = models.URLField(_("Ubuntu Wiki Page"), verify_exists=False, null=True, blank=True)
    web_url = models.URLField(_("Website"), verify_exists=False, null=True, blank=True)
    ml_url = models.URLField(_("Mailing List URL"), verify_exists=False, null=True, blank=True)
    forum_url = models.URLField(_("Forums URL"), verify_exists=False, null=True, blank=True)
    email = models.EmailField(_("Email Address"), null=True, blank=True)
    irc_chan = models.CharField(_("IRC Channel"),
                                max_length=25, null=True, blank=True,
                                help_text=_("IRC Channel name that is hosted on "
                                "the freenode IRC network. Ex. #ubuntu-chicago"))
    provides_support = models.BooleanField(_("Provides local support"),
                                           default=True)
    approved = models.BooleanField(_("Approved Team"), default=False)
    approved_date = models.DateField(_("Date Approved"), null=True, blank=True)
    expires_date = models.DateField(_("Date Expires"), null=True, blank=True)
    owner = models.SlugField(_("Launchpad Team Owner"), null=True, blank=False)
    admins = models.ManyToManyField(TeamAdministrator)
    
    objects = TeamManager()
    
    class Meta:
        db_table = 'teams'
        ordering = ('approved', 'name',)
        
    def __unicode__(self):
        return self.lp_name
    
