# -*- coding: utf-8 -*-

from django.template import RequestContext
from django.utils.translation import ugettext as _
from django.core import serializers

from django.contrib.auth.decorators import login_required
from django.core.urlresolvers import reverse
from django.http import HttpResponseRedirect

from django.shortcuts import get_object_or_404

from django import http

from django.contrib.auth.models import AnonymousUser

from common import launchpad
from common import utils
import common.views

from models import Team
import forms

def reapprovals(request):
    teams = Team.objects.all().order_by('expires_date')
    approved_teams = filter(lambda a: a.approved, teams)
    context = {
        'approved_teams': approved_teams,
    }
    return common.views.versioned_render('teams/team_reapprovals.html', 
                context, RequestContext(request))

def team_list(request):
    teams = Team.objects.all()
    context = {
        'pageSection': 'teams',
        'teams': utils.trans_sort_object_list(teams, 'name'),
    }
    return common.views.versioned_render('teams/team_list.html', context,
                  RequestContext(request))
    
def team_detail(request, team_slug):
    team_object = get_object_or_404(Team, lp_name=team_slug)
    context = {
        'pageSection': 'teams',
        'team': team_object,
    }
    return common.views.versioned_render('teams/team_detail.html', 
                                         context, RequestContext(request))


@login_required
def team_edit(request, team_slug):
    #get team
    team_object = get_object_or_404(Team, lp_name=team_slug)
    
    context = {
        'pageSection': 'teams',
        'team': team_object,
    }
    
    #check if user has needed rights
    is_on_lc = launchpad.is_user_on_loco_council(request.user.username)
    is_contact = launchpad.is_admin_or_owner(request.user.username, team_object)
    if not is_on_lc and not is_contact:
        request.user.message_set.create(message=_('You are not allowed to make changes to the team details.'))
        return HttpResponseRedirect( reverse( 'team-detail', args=[team_slug] ) )

    if request.method == "POST":
        if is_on_lc:
            form = forms.LoCoCouncilForm(data=request.POST, instance=team_object)
        else:
            form = forms.UpdateTeamForm(data=request.POST, instance=team_object)
        if form.is_valid():
            form.save()
            request.user.message_set.create(message=_('Team details updated'))
            return HttpResponseRedirect( reverse( 'team-detail', args=[team_slug] ) )
        else:
            request.user.message_set.create(message=_('Team details could not be saved.'))
    else:
        if is_on_lc:
            form = forms.LoCoCouncilForm(instance=team_object)
        else:
            form = forms.UpdateTeamForm(instance=team_object)
    
    return common.views.versioned_render('teams/team_update.html', 
                    {'form': form, 
                     'team':team_object, 
                     'user':request.user, 
                    })

def xml_team_data(request):
    XMLSerializer = serializers.get_serializer("xml")
    xml_serializer = XMLSerializer()
    xml_serializer.serialize(Team.objects.all())
    data = xml_serializer.getvalue()
    response = http.HttpResponse(data, mimetype='text/xml')
    response['Content-Disposition'] = 'filename=locoteams.xml'
    return response
